4.10.0 (2025-04-08)
===================

New features
------------

- enable easy overloading of storage CSRF policy
  (see https://forge.extranet.logilab.fr/cubicweb/cubicweb/-/issues/1080)
- entity add new helper methods:
  - :code:`cw_remove_relation` to remove only one
  - :code:`cw_remove_relations` to remove one or more

Bug fix
-------

skeleton: indicate that only Python 3 is supported

Miscellaneous
-------------

- YAMS: prepare for named parameters only
  (see https://forge.extranet.logilab.fr/open-source/yams/-/merge_requests/111)
- querier: add a bit of type checking
- :code:`black`: upgrade, as retro-compatibility was broken
- :code:`black`: feat(tox): upgrade Python version of from 3.7 to 3.9
